pub enum ExportError {
Other(&'static str),
Opaque,
}Expand description
An error that occurs while exporting secret key material.
Variants
Other(&'static str)
An unknown or internal error has occurred.
Opaque
The key is opaque and does not expose its key material.